==============
JTS Python
==============

.. currentmodule:: json_timeseries

.. Don't include inherited members to keep the doc short
.. autoclass:: json_timeseries.TsRecord
    :members:

.. autoclass:: json_timeseries.TimeSeries
    :members:

.. autoclass:: json_timeseries.JtsDocument
    :members:
